cgroup_traffic
cgroup_traffic is a library to monitor the network traffic of a cgroup. By passing a pid to this library, it will attach to the cgroup of the pid and monitor the network traffic of the cgroup.
It use ebpf program BPF_PROG_TYPE_CGROUP_SKB to monitor the network traffic. Now it’s only tested for Cgroup V2. It doesn’t support Cgroup V1, because it cannot parse the path of cgroup V1.
Structs
- Cgroup
Transmit Counter - The CgroupTransmitCounter is a struct to monitor the network traffic of a cgroup.
Constants
- SELF
- Helpful constant to monitor /proc/self/cgroup
Functions
- get_
pid_ cgroup - Get the cgroup path of a pid.
- init_
cgroup_ skb_ for_ process_ name - Initialize the eBPF program for monitoring the cgroup traffic of processes with the process name.
It will attach to a group of cgroups that the processes belongs to.
process_name can be
grep -Epattern(EREs), like “sshd|nginx|^rust-analyzer$”. - init_
cgroup_ skb_ monitor - Initialize the cgroup skb monitor.
- list_
pids_ in_ cgroup - List all PIDs in a cgroup.